.. :changelog:

History
=======

0.2.0
-----
* Daemon mode
* Logging (+ log files)
* Global config file (minipyp.conf)
* Directory-specific config files (.minipyp)

0.1.0b1
-------
* Now tracking changes